from setuptools import setup, find_packages

setup(
    name='chinese1',
    version='0.1',
    packages=find_packages(),
    install_requires=[
        # 列出依赖的库
    ],
    description='A brief description of your module',
    author='xiaotbl',
    author_email='monios114514@outlook.com',
    url='https://github.com/yourusername/yourrepository',  # 可选
)
